# passive_two_link.py
#
# Sample Webots controller file for driving the two-link arm
# with a driven base joint and a passive distal joint.

# No copyright, 2020, Garth Zeglin.  This file is
# explicitly placed in the public domain.

# Import the Webots simulator API.
from controller import Robot

print("passive_two_link.py waking up.")

# Request a proxy object for the robot to control
robot = Robot()

# Fetch a handle for the base joint motor.
j0 = robot.getMotor('motor1')

# Configure the motor for velocity control by setting
# the position target to infinity.
j0.setPosition(float('inf'))

# Start out with a 3 radian/second target rotational
# velocity (roughly 180 deg/sec).
j0.setVelocity(3)

# Run loop to execute a periodic script until the simulation quits.
while True:

    # Run for two seconds, then change the target velocity.
    # If the controller returns -1, the simulator is quitting.
    status = robot.step(2000) # milliseconds
    if status == -1: break
    j0.setVelocity(0)

    # Run for two seconds, then change the target velocity.    
    status = robot.step(2000) # milliseconds
    if status == -1: break
    j0.setVelocity(3)
    
